@@ -3,6 +3,9 @@
 #include "../debug/Log.hpp"
 #include <memory>
 
+#include <hyprutils/os/Process.hpp>
+using namespace Hyprutils::OS;
+
 bool vectorDeltaLessThan(const Vector2D& a, const Vector2D& b, const float& delta) {
     return std::abs(a.x - b.x) < delta && std::abs(a.y - b.y) < delta;
 }
@@ -12,15 +15,8 @@ bool vectorDeltaLessThan(const Vector2D& a, const Vector2D& b, const Vector2D& d
 }
 
 std::string execAndGet(const char* cmd) {
-    std::array<char, 128>                          buffer;
-    std::string                                    result;
-    const std::unique_ptr<FILE, decltype(&pclose)> pipe(popen(cmd, "r"), pclose);
-    if (!pipe) {
-        Debug::log(ERR, "execAndGet: failed in pipe");
+    CProcess proc("/bin/bash", {"-c", cmd});
+    if (!proc.runSync())
         return "";
-    }
-    while (fgets(buffer.data(), buffer.size(), pipe.get()) != nullptr) {
-        result += buffer.data();
-    }
-    return result;
+    return proc.stdOut();
 }
